pub async fn open(
source: impl ReadSeek + 'static,
) -> Result<Hff<AsyncStdReader>>Expand description
Opens the input and maintains it for random access to the metadata and chunks.
pub async fn open(
source: impl ReadSeek + 'static,
) -> Result<Hff<AsyncStdReader>>Opens the input and maintains it for random access to the metadata and chunks.